Opinion & Order Search

Sign In

Print

- By Party Name
- By Docket Number
- By Keyword
- Advanced

Use the By Party Name search to locate the Court opinions and orders for a specific party name. The party name can be the name of an individual or organization. Do not include a comma and use only one space to separate names. Search Tips
Party Name:
(Lastname Firstname Middle Initial OR Company Name)
Party Name is required Party Name must contain at least 4 characters
Select Court:

Supreme Court
Court of Appeals
Both

Please select a court
Use the By Docket Number search to locate the Court opinions and orders for a specific case docket number. Choose either Supreme Court or Court of Appeals. Search Tips
Case Docket Number: Case Docket Number must be a valid number less than 999999 Case Docket Number is required
Select Court:

Supreme Court
Court of Appeals

Please select a court
Use the By Keyword search to perform a full text search on all Court opinions and orders based on a specific keyword. Select a search scope and then type the keyword or phrase. Search Tips

Use the Advanced search to locate Court opinions and orders by selecting criteria in the provided fields. The required fields are the Date and Status fields. Both of these fields have default values. The remaining fields are optional. Search Tips
Author:
Panel Member:
Case Type:
Case Nature is required
Lower Court:
Lower Court is required
Status:
Status is required
Date: Beginning date required Invalid date
Through: Invalid date
Color Key:
Case title appears in red for Supreme Court opinions.
Case title appears in blue for Court of Appeals published opinions.
Case title appears in black for Court of Appeals unpublished opinions.
Case title appears in green for orders.
& signifies that the document is the official reported version of the opinion.
Advanced Opinions & Orders Search Results -
Records 1 - 25 of 272
Next > Last >>

- CASE NUMBER
- CASE DETAILS
- DOWNLOAD

- 1
- 311059
- - - ESTATE OF IVORY R IVEY V CITY OF DETROIT
    - Release Date: 9/18/2014
    - Lower Court: WAYNE CIRCUIT COURT
    - COA Opinion - Per Curiam - Unpublished
    - Case Type: Summary Disposition Granted
  - - Judge(s): DSO KJ PDO
    - Lower Court No. 12-001913-NI
    - View Docket Sheet

- 2
- 314824
- - - SYNTHIA J SHARIFF V SHIRAZ H SHARIFF
    - Release Date: 9/18/2014
    - Lower Court: SAGINAW CIRCUIT COURT
    - COA Opinion - Per Curiam - Unpublished
    - Case Type: Divorce Judgment
  - - Judge(s): CMM PMD SLB
    - Lower Court No. 09-003865-DM
    - View Docket Sheet

- 3
- 314824
- - - SYNTHIA J SHARIFF V SHIRAZ H SHARIFF
    - Release Date: 9/18/2014
    - Lower Court: SAGINAW CIRCUIT COURT
    - COA Opinion - Concurring
    - Case Type: Divorce Judgment
  - - Judge(s): CMM
    - Lower Court No. 09-003865-DM
    - View Docket Sheet

- 4
- 314830
- - - ESTATE OF MICHAEL RAYMOND SHEKOSKI V MICHAEL GARRETT BINDIG
    - Release Date: 9/18/2014
    - Lower Court: MACOMB CIRCUIT COURT
    - COA Opinion - Per Curiam - Unpublished
    - Case Type: Judgment for Plaintiff
  - - Judge(s): DSO KJ PDO
    - Lower Court No. 2010-001959-NI
    - View Docket Sheet

- 5
- 315030
- - - ANGELA SHAFT V JACKSON NATIONAL LIFE INSURANCE COMPANY
    - Release Date: 9/18/2014
    - Lower Court: INGHAM CIRCUIT COURT
    - COA Opinion - Per Curiam - Unpublished
    - Case Type: Summary Disposition Denied
  - - Judge(s): ETF HWS WCW
    - Lower Court No. 12-000070-CL
    - View Docket Sheet

- 6
- 315030
- - - ANGELA SHAFT V JACKSON NATIONAL LIFE INSURANCE COMPANY
    - Release Date: 9/18/2014
    - Lower Court: INGHAM CIRCUIT COURT
    - COA Opinion - Dissenting
    - Case Type: Summary Disposition Denied
  - - Judge(s): ETF
    - Lower Court No. 12-000070-CL
    - View Docket Sheet

- 7
- 316236
- - - VICTOR VINCENT VALENTINE V SHARON L VALENTINE
    - Release Date: 9/18/2014
    - Lower Court: KALAMAZOO CIRCUIT COURT
    - COA Opinion - Per Curiam - Unpublished
    - Case Type: Alimony
  - - Judge(s): DBS WCW CDS
    - Lower Court No. 1980-002751-DM
    - View Docket Sheet

- 8
- 316359
- - - ROBERT CARR V STARR INDEMNITY & LIABILITY COMPANY
    - Release Date: 9/18/2014
    - Lower Court: WAYNE CIRCUIT COURT
    - COA Opinion - Per Curiam - Unpublished
    - Case Type: Summary Disposition Granted
  - - Judge(s): DSO KJ PDO
    - Lower Court No. 12-006002-NF
    - View Docket Sheet

- 9
- 316409
- - - ESTATE OF SANDRA LYNN ROBERTS V DANIEL GADZINSKI MD
    - Release Date: 9/18/2014
    - Lower Court: WAYNE CIRCUIT COURT
    - COA Opinion - Per Curiam - Unpublished
    - Case Type: Civil Miscellaneous
  - - Judge(s): DSO KJ PDO
    - Lower Court No. 11-010725-NH
    - View Docket Sheet

- 10
- 316414
- - - LAMAR LEMMONS V CRYSTAL IRELAND
    - Release Date: 9/18/2014
    - Lower Court: WAYNE CIRCUIT COURT
    - COA Opinion - Per Curiam - Unpublished
    - Case Type: Attorney Fees & Costs
  - - Judge(s): DSO KJ PDO
    - Lower Court No. 11-012120-CH
    - View Docket Sheet

- 11
- 316556
- - - PEOPLE OF MI V TREMAINE RANDALL ROSS
    - Release Date: 9/18/2014
    - Lower Court: OAKLAND CIRCUIT COURT
    - COA Opinion - Per Curiam - Unpublished
    - Case Type: Criminal Miscellaneous
  - - Judge(s): DSO KJ PDO
    - Lower Court No. 2012-243814-FH
    - View Docket Sheet

- 12
- 316600
- - - CATHERINE N MCCARTHY V CITY OF TRENTON
    - Release Date: 9/18/2014
    - Lower Court: WAYNE CIRCUIT COURT
    - COA Opinion - Per Curiam - Unpublished
    - Case Type: Summary Disposition Denied - Gov'tal Immunity
  - - Judge(s): PMM KFK MJK
    - Lower Court No. 12-016668-NO
    - View Docket Sheet

- 13
- 316600
- - - CATHERINE N MCCARTHY V CITY OF TRENTON
    - Release Date: 9/18/2014
    - Lower Court: WAYNE CIRCUIT COURT
    - COA Opinion - Concurring
    - Case Type: Summary Disposition Denied - Gov'tal Immunity
  - - Judge(s): MJK
    - Lower Court No. 12-016668-NO
    - View Docket Sheet

- 14
- 316690
- - - MICHELLE DAWN REPPEN V WILLIAM DAVID REPPEN
    - Release Date: 9/18/2014
    - Lower Court: LIVINGSTON CIRCUIT COURT
    - COA Opinion - Per Curiam - Unpublished
    - Case Type: Attorney Fees & Costs
  - - Judge(s): CMM PMD SLB
    - Lower Court No. 08-040669-DM
    - View Docket Sheet

- 15
- 316862
- - - PEOPLE OF MI V ANTHONY DERRICK CHANDLER
    - Release Date: 9/18/2014
    - Lower Court: WASHTENAW CIRCUIT COURT
    - COA Opinion - Per Curiam - Unpublished
    - Case Type: CSC-1
  - - Judge(s): CMM PMD SLB
    - Lower Court No. 12-000935-FH
    - View Docket Sheet

- 16
- 318105
- - - IN RE PAYNE/PUMPHREY/FORTSON MINORS
    - Release Date: 9/18/2014
    - Lower Court: CALHOUN JUVENILE DIVISION
    - COA Opinion - Per Curiam - Unpublished
    - Case Type: Termination of Parental Rights
  - - Judge(s): ETF ELG AK
    - Lower Court No. 2009-003732-NA
    - View Docket Sheet

- 17
- 318163
- - - IN RE PAYNE MINORS
    - Release Date: 9/18/2014
    - Lower Court: CALHOUN JUVENILE DIVISION
    - COA Opinion - Per Curiam - Unpublished
    - Case Type: Termination of Parental Rights
  - - Judge(s): ETF ELG AK
    - Lower Court No. 2009-003732-NA
    - View Docket Sheet

- 18
- 320045
- - - IN RE KEITH MINORS
    - Release Date: 9/18/2014
    - Lower Court: WAYNE JUVENILE DIVISION
    - COA Opinion - Per Curiam - Unpublished
    - Case Type: Termination of Parental Rights
  - - Judge(s): JPH KTW KFH
    - Lower Court No. 96-336424-NA
    - View Docket Sheet

- 19
- 320912
- - - IN RE ROBERTS MINORS
    - Release Date: 9/18/2014
    - Lower Court: BERRIEN JUVENILE DIVISION
    - COA Opinion - Per Curiam - Unpublished
    - Case Type: Termination of Parental Rights
  - - Judge(s): DBS WCW CDS
    - Lower Court No. 2012-000103-NA
    - View Docket Sheet

- 20
- 303816
- - - ROSEVILLE TOWNHOUSE COOPERATIVE V CITY OF ROSEVILLE
    - Release Date: 9/16/2014
    - Lower Court: TAX TRIBUNAL
    - COA Opinion - Per Curiam - Unpublished
    - Case Type: Tax Tribunal
  - - Judge(s): ETF ELG AK
    - Lower Court No. 00-269701
    - View Docket Sheet

- 21
- 304255
- - - ROGER BURNEY V CITY OF DETROIT
    - Release Date: 9/16/2014
    - Lower Court: WAYNE CIRCUIT COURT
    - COA Opinion - Per Curiam - Unpublished
    - Case Type: Summary Disposition Denied - Gov'tal Immunity
  - - Judge(s): PMM KFK MJK
    - Lower Court No. 10-005081-NZ
    - View Docket Sheet

- 22
- 305463
- - - WESTWICK SQUARE COOPERATIVE V CITY OF WAYNE
    - Release Date: 9/16/2014
    - Lower Court: TAX TRIBUNAL
    - COA Opinion - Per Curiam - Unpublished
    - Case Type: Tax Tribunal
  - - Judge(s): ETF ELG AK
    - Lower Court No. 00-269704
    - View Docket Sheet

- 23
- 306022
- - - HICKORY HOLLOW COOPERATIVE V CITY OF WAYNE
    - Release Date: 9/16/2014
    - Lower Court: TAX TRIBUNAL
    - COA Opinion - Per Curiam - Unpublished
    - Case Type: Tax Tribunal
  - - Judge(s): ETF ELG AK
    - Lower Court No. 00-277266
    - View Docket Sheet

- 24
- 308843
- - - PEOPLE OF MI V NILES LYNDON JOHNSON
    - Release Date: 9/16/2014
    - Lower Court: WASHTENAW CIRCUIT COURT
    - COA Opinion - Per Curiam - Unpublished
    - Case Type: Criminal Miscellaneous
  - - Judge(s): DBS JEM CDS
    - Lower Court No. 11-000798-FH
    - View Docket Sheet

- 25
- 308843
- - - PEOPLE OF MI V NILES LYNDON JOHNSON
    - Release Date: 9/16/2014
    - Lower Court: WASHTENAW CIRCUIT COURT
    - COA Opinion - Concurring
    - Case Type: Criminal Miscellaneous
  - - Judge(s): DBS
    - Lower Court No. 11-000798-FH
    - View Docket Sheet

Records 1 - 25 of 272
Next > Last >>